#[non_exhaustive]#[repr(u8)]pub enum Level {
Error = 1,
Warn = 2,
Info = 3,
Debug = 4,
Verbose = 5,
}Expand description
Represents logging levels of a Pinenut log.
The default value in Meta is Level::Info.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Error = 1
The error log level.
It is typically the highest level of severity and is used when an operation fails.
Warn = 2
The warning log level.
It is used when something unexpected happened, or there might be a problem in the near future.
Info = 3
The informational log level.
Infomational messages to track the general flow of the application.
Debug = 4
The debug log level.
Logs that contain information useful for debugging during development and troubleshooting.
Verbose = 5
The verbose log level.
Logs may include more information than the Debug level and are usually not
enabled in a production environment.